@@ -23,26 +23,21 @@
 #ifndef CANVAS_SUBGRAPH_H
 #define CANVAS_SUBGRAPH_H
 
+// lib
 #include "canvaselement.h"
 
-class QGraphicsScene;
-
 namespace KGraphViewer
 {
-  
 class GraphSubgraph;
-class DotGraphView;
 
-class CanvasSubgraph: public CanvasElement
+class CanvasSubgraph : public CanvasElement
 {
-  Q_OBJECT
+    Q_OBJECT
 public:
-  CanvasSubgraph(
-      DotGraphView* v, 
-      GraphSubgraph* s,
-      QGraphicsScene* c,
-      QGraphicsItem* parent = nullptr);
-  ~CanvasSubgraph() override {}
+    CanvasSubgraph(DotGraphView *v, GraphSubgraph *s, QGraphicsScene *c, QGraphicsItem *parent = nullptr);
+    ~CanvasSubgraph() override
+    {
+    }
 
 protected:
 };
@@ -50,6 +45,3 @@ protected:
 }
 
 #endif
-
-
-
