@@ -20,9 +20,10 @@
 #ifndef LAYOUTAGRAPHTHREAD_H
 #define LAYOUTAGRAPHTHREAD_H
 
-#include <QThread>
+// Qt
 #include <QSemaphore>
-
+#include <QThread>
+// Graphviz
 #include <graphviz/gvc.h>
 
 int threadsafe_wrap_gvLayout(GVC_t *gvc, graph_t *g, const char *engine);
@@ -30,24 +31,36 @@ int threadsafe_wrap_gvRender(GVC_t *gvc, graph_t *g, const char *format, FILE *o
 
 class LayoutAGraphThread : public QThread
 {
-  Q_OBJECT
+    Q_OBJECT
 public:
-  LayoutAGraphThread();
-  ~LayoutAGraphThread() override;
-  void layoutGraph(graph_t* graph, const QString& layoutCommand);
-  inline graph_t* g() {return m_g;}
-  inline GVC_t* gvc() {return m_gvc;}
-  inline const QString& layoutCommand() const {return m_layoutCommand;}
-  void processed_finished() { sem.release(); }
-  
+    LayoutAGraphThread();
+    ~LayoutAGraphThread() override;
+    void layoutGraph(graph_t *graph, const QString &layoutCommand);
+    inline graph_t *g()
+    {
+        return m_g;
+    }
+    inline GVC_t *gvc()
+    {
+        return m_gvc;
+    }
+    inline const QString &layoutCommand() const
+    {
+        return m_layoutCommand;
+    }
+    void processed_finished()
+    {
+        sem.release();
+    }
+
 protected:
-  void run() override;
+    void run() override;
 
 private:
-  QSemaphore sem;
-  QString m_layoutCommand;
-  graph_t* m_g;
-  GVC_t *m_gvc;
+    QSemaphore sem;
+    QString m_layoutCommand;
+    graph_t *m_g = nullptr;
+    GVC_t *m_gvc = nullptr;
 };
 
 #endif // LAYOUTAGRAPHTHREAD_H
